@@ -2,7 +2,7 @@
 #'
 #' Operations to manipulate or combine multiple frames of an image. Details below.
 #'
-#' For details see [Magick++ STL](https://www.imagemagick.org/Magick++/STL.html)
+#' For details see [Magick++ STL](https://imagemagick.org/Magick++/STL.html)
 #' documentation. Short descriptions:
 #'
 #'  - [image_animate] coalesces frames by playing the sequence and converting to `gif` format.
@@ -26,7 +26,7 @@
 #' @name animation
 #' @family image
 #' @aliases image_coalesce
-#' @param dispose a frame [disposal method](http://www.imagemagick.org/Usage/anim_basics/#dispose)
+#' @param dispose a frame [disposal method](https://legacy.imagemagick.org/Usage/anim_basics/#dispose)
 #' from [dispose_types()][dispose_types]
 #' @param fps frames per second. Ignored if `delay` is not `NULL`.
 #' @param delay delay after each frame, in 1/100 seconds.
@@ -53,7 +53,11 @@ image_animate <- function(image, fps = 10, delay = NULL, loop = 0,
                        optimize)
 }
 
-image_coalesce <- image_animate
+#' @export
+#' @rdname animation
+image_coalesce <- function(image){
+  magick_image_coalesce(image)
+}
 
 #' @export
 #' @rdname animation
