@@ -1,7 +1,7 @@
 #' Image Composite
 #'
 #' Similar to the ImageMagick `composite` utility: compose an image on top of another one using a
-#' [CompositeOperator](https://www.imagemagick.org/Magick++/Enumerations.html#CompositeOperator).
+#' [CompositeOperator](https://imagemagick.org/Magick++/Enumerations.html#CompositeOperator).
 #'
 #' The `image_composite` function is vectorized over both image arguments: if the first image has
 #' `n` frames and the second `m` frames, the output image will contain `n` * `m` frames.
@@ -19,13 +19,13 @@
 #' @param offset string with either a [gravity_type][gravity_types] or a [geometry_point][geometry_point]
 #' to set position of top image.
 #' @param operator string with a
-#' [composite operator](https://www.imagemagick.org/Magick++/Enumerations.html#CompositeOperator)
+#' [composite operator](https://imagemagick.org/Magick++/Enumerations.html#CompositeOperator)
 #' from [compose_types()][compose_types]
 #' @param composite_image composition image
 #' @param compose_args additional arguments needed for some composite operations
 #' @examples # Compose images using one of many operators
 #' imlogo <- image_scale(image_read("logo:"), "x275")
-#' rlogo <- image_read("https://developer.r-project.org/Logo/Rlogo-3.png")
+#' rlogo <- image_read("https://jeroen.github.io/images/Rlogo-old.png")
 #'
 #' # Standard is atop
 #' image_composite(imlogo, rlogo)
@@ -56,7 +56,7 @@ image_composite <- function(image, composite_image, operator = "atop",
 
 #' @export
 #' @rdname composite
-#' @param geometry a [geometry string](https://www.imagemagick.org/Magick++/Geometry.html)
+#' @param geometry a [geometry string](https://imagemagick.org/Magick++/Geometry.html)
 #' to set height and width of the border, e.g. `"10x8"`. In addition [image_frame] allows
 #' for adding shadow by setting an offset e.g. `"20x10+7+2"`.
 #' @examples
@@ -94,8 +94,8 @@ image_shadow_mask <- function(image, geometry = '50x10+30+30'){
 #' @rdname composite
 #' @inheritParams edges
 #' @examples image_shadow(imlogo)
-image_shadow <- function(image, color = 'black', bg = 'white', geometry = '50x10+30+30',
-                         operator = 'atop', offset = '+20+20'){
+image_shadow <- function(image, color = 'black', bg = 'none', geometry = '50x10+30+30',
+                         operator = 'copy', offset = '+20+20'){
   assert_image(image)
   geometry <- as.character(geometry)
   input <- image_background(image, color, flatten = TRUE)
@@ -105,3 +105,18 @@ image_shadow <- function(image, color = 'black', bg = 'white', geometry = '50x10
     image_composite(shadow[i], image[i], operator = operator, offset = offset)
   }))
 }
+
+#' @export
+#' @rdname composite
+#' @inheritParams edges
+#' @examples image_shade(imlogo)
+#' @param azimuth position of light source
+#' @param elevation position of light source
+#' @param color Set to true to shade the red, green, and blue components of the image.
+image_shade <- function(image, azimuth = 30, elevation = 30, color = FALSE){
+  assert_image(image)
+  azimuth <- as.numeric(azimuth)
+  elevation <- as.numeric(elevation)
+  color <- as.logical(color)
+  magick_image_shade(image, azimuth, elevation, color)
+}
